//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
// IStbTulsaCtl.h
// (C) Copyright 1998 by STB Systems, Inc.
//
// Interfaces for controlling the Stb Tulsa Mpeg/Video card
//
// 7/6/98
//
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
#ifndef _ISTBTULSACTL_H
#define _ISTBTULSACTL_H

#define MAX_STB_TULSA_CARDS		4			// Maximum number of Tulsa cards in a system

#ifndef STB_LIB_OBJECT
//////////////////////////////////////////////////////////////////////////
//  Guids and IIDs
//////////////////////////////////////////////////////////////////////////
DEFINE_GUID(CLSID_STBTControl, 0x9f645d30, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);

DEFINE_GUID(IID_ISTBTAudioControl,				0x9f645d21, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);
DEFINE_GUID(IID_ISTBTAnalogVideoDecoderControl, 0x9f645d22, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);
DEFINE_GUID(IID_ISTBTAnalogVideoEncoderControl, 0x9f645d23, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);
DEFINE_GUID(IID_ISTBTBoardControl,				0x9f645d24, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);
DEFINE_GUID(IID_ISTBTGenlockControl,			0x9f645d25, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);
DEFINE_GUID(IID_ISTBTMPEGDecoderControl,		0x9f645d26, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);
DEFINE_GUID(IID_ISTBTMPEGStatus,				0x9f645d27, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);
DEFINE_GUID(IID_ISTBTVBIControl,				0x9f645d28, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);
DEFINE_GUID(IID_ISTBTVideoControl,				0x9f645d29, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);
DEFINE_GUID(IID_ISTBTVerticalStatus,			0x9f645d2a, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);
//Reserved for ISTBTDebug						0x9f645d2b...			
//Reserved for IID_ISTBTDDSurfaceExt			0x9f645d2c...
DEFINE_GUID(IID_ISTBTTest,						0x9f645d2d, 0x14fa,0x11d2,0x8f, 0x78, 0x00, 0xa0, 0xc9, 0x82, 0xc6, 0x1a);

#endif // STB_LIB_OBJECT

//////////////////////////////////////////////////////////////////////////
//  Structures and types
//////////////////////////////////////////////////////////////////////////
// Definitions //


#define MAX_FRAME_LIST_ENTRIES	(64)		// Maximum number of entries in a frame list

////////////////////////////
//
typedef enum {
	OFFSET_POS = 0,							// Position in bytes
	OFFSET_TIME,							// Position in time units
	OFFSET_FRAME							// Position in frame units
} OFFSET_TYPE, *POFFSET_TYPE;


////////////////////////////
//
typedef struct {
	OFFSET_TYPE Type;						// Type of offset - see below
	ULONG hi;								// Most significant word of offset
	ULONG lo;								// Least significant word of offset
} MEDIA_OFFSET, *PMEDIA_OFFSET;


typedef enum {								// Tulsa board state
	BOARD_STAT_UNKNOWN = 0,					//  Unknown state
	BOARD_STAT_RESET,						//  Board has been reset
	BOARD_STAT_MONITOR,						//  Board is in debug monitor mode
	BOARD_STAT_RUNNING,						//  Board is running downloaded code
	BOARD_STAT_INITIALIZING					//  Board is initializing (after download)
} TULSA_BOARD_STATE, *PTULSA_BOARD_STATE;

typedef struct {							// Board status:
	TULSA_BOARD_STATE State;				//	Current state of the board
} TULSA_BOARD_STATUS, *PTULSA_BOARD_STATUS;


////////////////////////////
//
typedef enum {
	STATE_UNKNOWN = 0,						// Status not known
	STATE_STOPPED,							// Stopped
	STATE_PLAYING,							// Playing
	STATE_PAUSED,							// Paused
	STATE_ERROR,							// An error has stopped playback
	STATE_PLAY_PENDING,						// Play pending the completion of the
 											// previous play command or the 
 											// specified playback time
	STATE_PLAY_REQUESTED,					// Play has been requested
	STATE_STOP_REQUESTED,					// Stop has been requested
	STATE_PAUSE_REQUESTED,					// Pause has been requested
	STATE_RESUME_REQUESTED					// Resume has been requested
} DECODE_STATE, *PDECODE_STATE;


////////////////////////////
//
typedef struct {							// MPEG Decoder status:
	DECODE_STATE State;						//  State of decoder
	DWORD hStream;							//  Handle of stream being decoded
	MEDIA_OFFSET OffsetTime;				//  Current playback time (90KHz units)
	MEDIA_OFFSET OffsetPos;					//  Current playback position (bytes)
	MEDIA_OFFSET OffsetFrame;				//  Current frame being displayed
	DWORD StartingVertical;					//  Vertical on which playback started
	DWORD CurrentVertical;					//  Current board-level vertical count
} DECODE_STATUS, *PDECODE_STATUS;


////////////////////////////
//  Result codes 
typedef enum {
	SUCCESS = 0,
	ERR_CANNOT_OPEN_DRIVER = 0x800,			// Driver open failed
	ERR_CANNOT_GET_BOARD_ADDR,				// Driver failed getting board address
	ERR_DL_SREC_PARSE_ERROR,				// Download, SREC parse error
	ERR_DL_VERIFY_ERROR,					// Download, Verify error
	ERR_DL_OPEN_ERROR,						// Download, Cannot open file
	ERR_DL_READ_ERROR,						// Download, Read error
	ERR_DRIVER_NOT_OPEN,					// Driver not open
	ERR_CARD_NOT_AVAIL,						// Invalid card number or specified card is not available
	ERR_RESET_FAILED,						// Card reset failed
	ERR_CHAN_NOT_READY,						// Channel not ready for specified media control command
	ERR_NOT_PLAYING,						// Channel not playing
	ERR_NOT_PAUSED,							// Channel not paused
	ERR_CANNOT_OPEN_FILE,					// Failed opening file
	ERR_INVALID_DATA_SOURCE,				// Invalid data source specified
	ERR_SELF_TEST_NOT_COMPLETE,				// Diagnostics have not completed
	ERR_INVALID_PARAMETER,					// One or more of the parameters were invalid
	ERR_DUPLICATE_CARD_ID,					// One or more cards are configured with the same ID
	ERR_INVALID_BUFFER_CONFIG,				// Invalid Disk Read configuration specified
	ERR_CHANNEL_NOT_AVAIL,					// Specified channel not available on this board (ie third chan
											//  requested on a 2-port board)
	ERR_STREAM_NOT_AVAIL,					// Specified stream is not available
	ERR_BOARD_NOT_READY,					// Board is not properly initialized
	ERR_CARD_INIT_FAILURE					// Board failed to init properly
} TULSA_RESULT_ENUM, *PTULSA_RESULT_ENUM;

#define TULSA_RESULT HRESULT

#define TULSA_ERROR(e) MAKE_HRESULT(SEVERITY_ERROR, FACILITY_NULL, e)

////////////////////////////
//
typedef enum {								// Play mode options:
	PLAY_BOTH = 0,							// Play audio and video streams
	PLAY_VIDEO,								// Play only the video stream
	PLAY_AUDIO								// Play only the audio stream
} PLAY_MODE, *PPLAY_MODE;

////////////////////////////
//
typedef enum {								// Start mode options:
	START_NOW = 0,							//  Stop current playback (if any) and start this stream
	START_NEXT,								//  Wait until current playback finishes, and then start
	START_NEXT_PAUSE,						//  Wait until current playback finishes, then start this 
											//   stream, and then pause on the first frame
	START_SCHEDULED							//  Start at the scheduled time
} START_MODE, *PSTART_MODE;

////////////////////////////
//
typedef struct {							// Video output transition options:
	DWORD bBlankOnStartup;					//  MPEG decoder output is blanked until the first frame
											//   is displayed (else default to current blanking state
											//   as was setup by the previous clip)
	DWORD bBlankOnEOS;						//  MPEG decoder output is blanked at the end of the stream
											//   (else last frame is frozen)
	DWORD TransitionFrames;					//  Number of transition frames to be added at the end of the stream
} TRANSITION_OPTIONS, *PTRANSITION_OPTIONS;

////////////////////////////
//
typedef struct {							// MPEG playback options:
	PLAY_MODE PlayMode;						//  Playback mode
	START_MODE StartMode;					//  STartup mode
	DWORD StartTime;						//  Playback start time (in board time units) if StartMode
											//   is START_SCHEDULED
	DWORD AudioStreamID;					//  Audio stream ID to use
	MEDIA_OFFSET StartOffset;				//  Starting playback position
	MEDIA_OFFSET EndOffset;					//  Ending playback position
	TRANSITION_OPTIONS TransitionOptions;	// Transition options
	DWORD bLoopPlay;						//  Repeat playback if TRUE
} PLAY_OPTIONS, *PPLAY_OPTIONS;


////////////////////////////
//
typedef struct {
	ULONG VerBoardRom;						// ROM version
	ULONG VerDriver;						// NT driver version
	ULONG VerDll;							// DLL version
	ULONG VerBoardCode;						// Downloaded i960 code version
} TULSA_BOARD_VERSION, *PTULSA_BOARD_VERSION;


////////////////////////////
//	Audio Sources 
typedef enum {
	AUDIO_MPEG_DEC = 0,						// Decoded MPEG audio
	AUDIO_ANALOG_IN,						// External analog audio input
	AUDIO_EXT_DIGITAL_IN,					// External I2S digital input
	NUM_AUDIO_SOURCES						// Number of sources
} AUDIO_SOURCE, *PAUDIO_SOURCE;



////////////////////////////
// Video Ports 
typedef enum {
	VIDEO_PORT_YUV_PRI = 0,					// Primary video port on YUV processor
	VIDEO_PORT_YUV_SEC,						// Secondary video port on YUV processor
	VIDEO_PORT_RGB,							// Video port on RGB processor
	NUM_VIDEO_PORTS							// Number of video ports
} VIDEO_PORT_ID, *PVIDEO_PORT_ID;

////////////////////////////
// Video Sources 
typedef enum {
	VIDEO_MPEG_DEC = 0,						// Decoded MPEG video
	VIDEO_ANALOG_IN,						// External analog video input
	VIDEO_EXT_DIGITAL,						// External digital input
	NUM_VIDEO_SOURCES						// Number of sources
} VIDEO_SOURCE, *PVIDEO_SOURCE;

////////////////////////////
// Genlock Sources
typedef enum {
	GENLOCK_SRC_VIDEO_IN = 0,				// Composite video input
	GENLOCK_SRC_GENLOCK_IN,					// Genlock input
	NUM_GENLOCK_SOURCES						// Number of genlock source
} GENLOCK_SOURCE, *PGENLOCK_SOURCE;



////////////////////////////
//
#define MAX_VID_CONFIG_REGS	256				// Max number of configuration registers 

////////////////////////////
//
typedef struct {							// Analog video decoder configuration
	BYTE CtlConfig[MAX_VID_CONFIG_REGS];	// Control register configuration values
	BYTE LutConfig[MAX_VID_CONFIG_REGS];	// LUT configuration values
	BOOL bCtlConfigValid;					// TRUE if the control reg config values are valid
	BOOL bLutConfigValid;					// TRUE if the LUT config values are valid
	BOOL bACCEnable;						// TRUE if Auto color correction should be enabled
} ANALOG_VIDEO_DECODER_CONFIG, *PANALOG_VIDEO_DECODER_CONFIG;

////////////////////////////
//
typedef struct {							// Analog video encoder configuration
	BYTE CtlConfig[MAX_VID_CONFIG_REGS];	// Control register configuration values
	BYTE LutConfig[MAX_VID_CONFIG_REGS];	// LUT configuration values
} ANALOG_VIDEO_ENCODER_CONFIG, *PANALOG_VIDEO_ENCODER_CONFIG;

////////////////////////////
//
typedef struct {							// Genlock decoder configuration
	BYTE CtlConfig[MAX_VID_CONFIG_REGS];	// Control register configuration values
} GENLOCK_CONFIG, *PGENLOCK_CONFIG;


////////////////////////////
//
typedef enum {
	CALL_CANCEL = 0,						// Cancel the callback
	CALL_EVERY,								// callback on every vertical
	CALL_ABSOLUTE,							// callback when absolute count occurs
	CALL_RELATIVE							// callback when count relative to current occurs
} VERTICAL_CALL_TYPE, *PVERTICAL_CALL_TYPE;


////////////////////////////
//
typedef enum {								// Video Output Modes:
	VIDEO_MODE_NTSC = 0,					// NTSC
	VIDEO_MODE_PAL,							//  PAL I,B,N
	NUM_VIDEO_MODES							// Number of video modes
} VIDEO_MODE, *PVIDEO_MODE;	

////////////////////////////
// Configuration related structures 
#define INVALID_CARD_ID		0xff			// Invalid card ID

////////////////////////////
//
typedef struct {							// Disk read buffering configuration:
	DWORD BufferCount;						// Number of disk buffers per channel
	DWORD BufferSize;						// Size of each disk buffer in bytes
} DISK_READ_CONFIG, *PDISK_READ_CONFIG;
							
////////////////////////////
//
typedef struct {		
	DISK_READ_CONFIG DiskReadConfig;		// Read configuration 
	DWORD AudioDelay;						// Audio delay in milliseconds
	AUDIO_SOURCE AudioSource;				// Current audio source
	DWORD AudioVolume[NUM_AUDIO_SOURCES];	// Audio volume for each source (in dB)
	BOOL bLine21PassThru;					// TRUE if line 21 data should be passed-thru
	VIDEO_MODE VideoMode;					// Video mode
	VIDEO_SOURCE VideoSource[NUM_VIDEO_PORTS]; // Video source per video port
	BYTE bDisableGenLock;					// TRUE if GenLock should be inhibited 
	GENLOCK_SOURCE GenlockSource;			// Genlock input source
	BYTE bDisableAVSync;					// TRUE if A/V sync should be inhibited; FALSE normal operation
	LONG AudioPhase[NUM_AUDIO_SOURCES];		// Audio phase offset for each source
	BOOL bACCEnable;						// TRUE if auto color correction should be enabled
	int ThreadPriority;						// Thread priority to be used for threads of this object. 
											//  The minimum value should be THREAD_PRIORITY_ABOVE_NORMAL.
} TULSA_CONFIG, *PTULSA_CONFIG;

////////////////////////////
// Diagnostics-related structures 
typedef struct {
	DWORD VidEncoderID;						// ID of video encoder IC
	DWORD bAVDecoderRegTestPassed;			// TRUE if register test passed
	DWORD bAVDecoderMemTestPassed;			// TRUE if memory test passed
	DWORD bAVDecoderVidCDTestPassed;		// TRUE if video compressed data test passed
	DWORD bAVDecoderAudCDTestPassed;		// TRUE if audio compressed data test passed
	DWORD bAVDecoderVidIntTestPassed;		// TRUE if video interrupt test passed
	DWORD bVidEncoderCommTestPassed;		// TRUE if video encoder communications test passed
	DWORD bVidDecoderCommTestPassed;		// TRUE if video decoder communications test passed
	DWORD bVidGLDecoderCommTestPassed;		// TRUE if video genlock decoder communications test passed
	DWORD bMixerTestPassed;					// TRUE if video mixer communications test passed
} TULSA_CHAN_TEST_STATUS, *PTULSA_CHAN_TEST_STATUS;


////////////////////////////
//
typedef struct {
	DWORD bDiagsFinished;					// TRUE if all tests have been completed
	TULSA_CHAN_TEST_STATUS ChanStatus;		// Channel-level test info
} TULSA_TEST_STATUS, *PTULSA_TEST_STATUS;



//////////////////////////////////////////////////////////////////////////
//----------------------------------------------------------------------//
//////////////////////////////////////////////////////////////////////////

#ifndef STB_LIB_OBJECT

//////////////////////////////////////////////////////////////////////////
//  ISTBTAudioControl
//////////////////////////////////////////////////////////////////////////
#undef INTERFACE
#define INTERFACE ISTBTAudioControl
DECLARE_INTERFACE_( ISTBTAudioControl, IUnknown )
{
    /*** ISTBTAudioControl methods ***/
    STDMETHOD(GetDelay)(THIS_ 
							PDWORD pAudioDelay) PURE;
    STDMETHOD(GetSource)(THIS_ 
							PAUDIO_SOURCE pAudioSource) PURE;
    STDMETHOD(GetVolume)(THIS_ 
							AUDIO_SOURCE AudioSource, 
							PDWORD pVolume) PURE;
    STDMETHOD(SetDelay)(THIS_ 
							DWORD AudioDelay) PURE;
    STDMETHOD(SetSource)(THIS_ 
							AUDIO_SOURCE AudioSource) PURE;
    STDMETHOD(SetVolume)(THIS_ 
							AUDIO_SOURCE AudioSource, 
							DWORD Volume) PURE;
    STDMETHOD(GetPhaseOffset)(THIS_ 
							AUDIO_SOURCE AudioSource, 
							PLONG pOffset) PURE;
    STDMETHOD(SetPhaseOffset)(THIS_ 
							AUDIO_SOURCE AudioSource, 
							LONG Offset) PURE;
};



//////////////////////////////////////////////////////////////////////////
//  ISTBTAnalogVideoDecoderControl
//////////////////////////////////////////////////////////////////////////
#undef INTERFACE
#define INTERFACE ISTBTAnalogVideoDecoderControl
DECLARE_INTERFACE_( ISTBTAnalogVideoDecoderControl, IUnknown )
{
    STDMETHOD(GetConfig)(THIS_ 
							VIDEO_MODE VideoMode,
							PANALOG_VIDEO_DECODER_CONFIG pDecoderConfig) PURE;
    STDMETHOD(SetConfig)(THIS_ 
							VIDEO_MODE VideoMode,
							PANALOG_VIDEO_DECODER_CONFIG pDecoderConfig) PURE;
};



//////////////////////////////////////////////////////////////////////////
//  ISTBTAnalogVideoEncoderControl
//////////////////////////////////////////////////////////////////////////
#undef INTERFACE
#define INTERFACE ISTBTAnalogVideoEncoderControl
DECLARE_INTERFACE_( ISTBTAnalogVideoEncoderControl, IUnknown )
{
    STDMETHOD(GetConfig)(THIS_ 
							VIDEO_MODE VideoMode,
							PANALOG_VIDEO_ENCODER_CONFIG pEncoderConfig) PURE;
    STDMETHOD(SetConfig)(THIS_ 
							VIDEO_MODE VideoMode,
							PANALOG_VIDEO_ENCODER_CONFIG pEncoderConfig) PURE;
};




//////////////////////////////////////////////////////////////////////////
//  ISTBTBoardControl
//////////////////////////////////////////////////////////////////////////
#undef INTERFACE
#define INTERFACE ISTBTBoardControl
DECLARE_INTERFACE_( ISTBTBoardControl, IUnknown )
{
    STDMETHOD(CallOnBoardVertical)(THIS_ 
							DWORD BoardVertical,
							VERTICAL_CALL_TYPE CallType,
							LPVOID pObject) PURE;
    STDMETHOD(ConvertMillisecondsToBoardVertical)(THIS_ 
							DWORD Milliseconds, 
							PDWORD pBoardVertical) PURE;
    STDMETHOD(EnableBypass)(THIS_ 
							BOOL bBypass) PURE;
    STDMETHOD(GetBoardNumber)(THIS_ 
							PDWORD pCardNumber) PURE;
    STDMETHOD(GetBoardStatus)(THIS_ 
							PTULSA_BOARD_STATUS pStatus) PURE;
    STDMETHOD(GetBoardVertical)(THIS_ 
							PDWORD pBoardVertical) PURE;
    STDMETHOD(GetBoardVersion)(THIS_ 
							PTULSA_BOARD_VERSION pVersion) PURE;
    STDMETHOD(GetSelfTestResults)(THIS_ 
							PTULSA_TEST_STATUS pTestStatus) PURE;
    STDMETHOD(InitBoard)(THIS_
							PTULSA_CONFIG pConfig) PURE;
};



//////////////////////////////////////////////////////////////////////////
//  ISTBTGenlockControl
//////////////////////////////////////////////////////////////////////////
#undef INTERFACE
#define INTERFACE ISTBTGenlockControl
DECLARE_INTERFACE_( ISTBTGenlockControl, IUnknown )
{
    STDMETHOD(GetConfig)(THIS_ 
							VIDEO_MODE VideoMode,
							PGENLOCK_CONFIG pGenlockConfig) PURE;
    STDMETHOD(GetSource)(THIS_ 
							PGENLOCK_SOURCE pGenlockSource) PURE;
    STDMETHOD(SetConfig)(THIS_ 
							VIDEO_MODE VideoMode,
							PGENLOCK_CONFIG pGenlockConfig) PURE;
    STDMETHOD(SetSource)(THIS_ 
							GENLOCK_SOURCE GenlockSource) PURE;
};


//////////////////////////////////////////////////////////////////////////
//  ISTBTMPEGDecoderControl
//////////////////////////////////////////////////////////////////////////
#undef INTERFACE
#define INTERFACE ISTBTMPEGDecoderControl
DECLARE_INTERFACE_( ISTBTMPEGDecoderControl, IUnknown )
{
    STDMETHOD(GetStatus)(THIS_ 
							DWORD hStream, 
							PDECODE_STATUS pStatus) PURE;
    STDMETHOD(NotifyAt)(THIS_ 
							DWORD hStream, 
							PDWORD pFrameList, 
							DWORD CntFrameList, 
							LPVOID pObject) PURE;
    STDMETHOD(Pause)(THIS_ 
							DWORD hStream) PURE;
    STDMETHOD(Play)(THIS_ 
							TCHAR* pFilename, 
							PPLAY_OPTIONS pPlayOptions,
							PDWORD phStream,
							LPVOID pObject) PURE;
    STDMETHOD(Resume)(THIS_ 
							DWORD hStream) PURE;
    STDMETHOD(Stop)(THIS_ 
							DWORD hStream) PURE;
};



//////////////////////////////////////////////////////////////////////////
//  ISTBTMPEGStatus
//////////////////////////////////////////////////////////////////////////
#undef INTERFACE
#define INTERFACE ISTBTMPEGStatus
DECLARE_INTERFACE_( ISTBTMPEGStatus, IUnknown )
{
    STDMETHOD(NotifyAtStatus)(THIS_ 
							DWORD hStream,
							DWORD FrameNumber) PURE;
    STDMETHOD(PlayStatus)(THIS_ 
							DWORD hStream,
							PDECODE_STATUS pStatus) PURE;
};



//////////////////////////////////////////////////////////////////////////
//  ISTBTVBIControl
//////////////////////////////////////////////////////////////////////////
#undef INTERFACE
#define INTERFACE ISTBTVBIControl
DECLARE_INTERFACE_( ISTBTVBIControl, IUnknown )
{
    STDMETHOD(EnableLine21PassThru)(THIS_ 
							BOOL bEnable) PURE;
};


//////////////////////////////////////////////////////////////////////////
//  ISTBTVideoControl
//////////////////////////////////////////////////////////////////////////
#undef INTERFACE
#define INTERFACE ISTBTVideoControl
DECLARE_INTERFACE_( ISTBTVideoControl, IUnknown )
{
    STDMETHOD(GetVideoPortSource)(THIS_ 
							VIDEO_PORT_ID VideoPortID,
							PVIDEO_SOURCE pVideoSource) PURE;
    STDMETHOD(SetVideoPortSource)(THIS_ 
							VIDEO_PORT_ID VideoPortID,
							VIDEO_SOURCE VideoSource) PURE;
};


//////////////////////////////////////////////////////////////////////////
//  ISTBTVerticalStatus
//////////////////////////////////////////////////////////////////////////
#undef INTERFACE
#define INTERFACE ISTBTVerticalStatus
DECLARE_INTERFACE_( ISTBTVerticalStatus, IUnknown )
{
    STDMETHOD(VerticalOccurred)(THIS_ 
							DWORD VerticalNumber) PURE;
};


//////////////////////////////////////////////////////////////////////////
//  ISTBTTest
//////////////////////////////////////////////////////////////////////////
#undef INTERFACE
#define INTERFACE ISTBTTest
DECLARE_INTERFACE_( ISTBTTest, IUnknown )
{
	STDMETHOD(EnableVideoTestMode)(THIS_
							BOOL bEnable) PURE;
	STDMETHOD(EnableTestPattern)(THIS_
							BOOL bEnable,
							int PatternID) PURE;
};




#endif // STB_LIB_OBJECT


#endif
